"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dub.types import BaseModel
from dub.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing_extensions import Annotated, TypedDict


class GetWorkspaceRequestTypedDict(TypedDict):
    id_or_slug: str
    r"""The ID or slug of the workspace."""


class GetWorkspaceRequest(BaseModel):
    id_or_slug: Annotated[
        str,
        pydantic.Field(alias="idOrSlug"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The ID or slug of the workspace."""
