"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dub.types import BaseModel
from dub.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class DeleteDomainRequestTypedDict(TypedDict):
    slug: str
    r"""The domain name."""


class DeleteDomainRequest(BaseModel):
    slug: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The domain name."""


class DeleteDomainResponseBodyTypedDict(TypedDict):
    r"""The domain was deleted."""

    slug: str
    r"""The domain name."""


class DeleteDomainResponseBody(BaseModel):
    r"""The domain was deleted."""

    slug: str
    r"""The domain name."""
