"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dub.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class AnalyticsCountTypedDict(TypedDict):
    clicks: NotRequired[float]
    r"""The total number of clicks"""
    leads: NotRequired[float]
    r"""The total number of leads"""
    sales: NotRequired[float]
    r"""The total number of sales"""
    sale_amount: NotRequired[float]
    r"""The total amount of sales, in cents"""


class AnalyticsCount(BaseModel):
    clicks: Optional[float] = 0
    r"""The total number of clicks"""

    leads: Optional[float] = 0
    r"""The total number of leads"""

    sales: Optional[float] = 0
    r"""The total number of sales"""

    sale_amount: Annotated[Optional[float], pydantic.Field(alias="saleAmount")] = 0
    r"""The total amount of sales, in cents"""
